Performs a lightweight HTTP check to verify that the Kolada API is reachable. This is primarily useful for guarding examples and tests.
Performs a lightweight HTTP check to verify that the Kolada API is reachable. This is primarily useful for guarding examples and tests.