Skip to contents

Returns the path to the persistent cache directory used by rKolada. The directory is created if it does not exist.

Usage

kolada_cache_dir()

Value

A string containing the path to the cache directory.