R/aaa_utils.R
kolada_cache_dir.Rd
Returns the path to the persistent cache directory used by rKolada. The directory is created if it does not exist.
kolada_cache_dir()
A string containing the path to the cache directory.